package com.lantone.qc.trans.wenfuyi.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Element;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @author: rengb
 * @time: 2020/9/28 16:36
 */
@Slf4j
public class OperationRecordHtmlAnalysis implements WenFuYiHtmlAnalysis {

    private String modeId = "17";

    @Override
    public Map<String, String> analysis(String... args) {
        Map<String, String> map = Maps.newLinkedHashMap();
        try {
            String html = args[0];
            String recTitle = args[1];
            String recTypeId = args[2];
            String content = Jsoup.parse(html).selectFirst("body").children().text();
            analysisGeneral(content, map);
            WenFuYiHtmlAnalysisUtil.mapValueRemoveStartColon(map);
            CommonAnalysisUtil.makeEmpty(map, "医生签名");
            WenFuYiHtmlAnalysisUtil.insertModuleId(modeId, recTypeId, map);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return map;
    }

    private void analysisGeneral(String content, Map<String, String> map) {
        content = content.replaceAll("注:如果手术记录中的手术日期有变更，必须重新点击“编辑手术名称”按钮保存。", "");
        List<String> titles = Lists.newArrayList(
                "手术开始时间", "手术结束时间", "手术日期", "术前诊断", "术中诊断", "手术名称", "主刀医师", "一助", "二助", "麻醉方式", "麻醉者", "体位及手术径路", "探查(术中所见)",
                "操作步骤", "手术经过(手术小结)", "主刀签名", "记录者", "记录时间", "记录日期"
        );
        titles = CommonAnalysisUtil.sortTitles(titles, content);
        CommonAnalysisUtil.cutByTitlesNoColon(content, titles, 0, map);
    }

}